New Year's Eve Hairstyles You Can Wear From Office to Party - SELF
Description: Because theres no time to change your hair before the clock strikes midnight.
Keywords: braids, buns, Emma Stone, jaime king, Jessica Alba, New Year's Eve, Waves

Close
Best Stretches For Flexibility
Cozy Vegetarian Winter Soups
21-Day Time Makeover
Yoga For Your Abs
Tone Up With 6 Power Moves
FLASH WHAT'S NEW NOW
2014
Dec 29
10:00 PM
Beauty
By Shannon Farrell

# New Year’s Eve Hairstyles You Can Wear From Office to Party

Starting the New Year on a good note means skipping the stress—especially when it comes to your hair! But since many of us will be working in the hours leading up to the ball drop (often with little to no time to adjust between office and party) our suggestion is to prep your locks in the AM. With the right style and a few night-appropriate tricks, your hair won't need much upkeep to make it to midnight.

## Loose Waves

Start with structured waves in the morning, wrapping small sections of hair (1-1 1/2-inch pieces) around a 1-inch curling iron for 20 to 30 seconds. Brush the ringlets out and throughout the day, they’ll smooth to soft waves. After work, apply a texturizing spray into the hair, spraying and scrunching each section to increase volume.

## Glam Topknot

The secret to a topknot is in the volume. In the morning apply a generous amount of dry shampoo from the scalp to the tip, scrunching the hair to add fullness. Then pull the hair up into a twisted topknot towards the top of the head. Hold with hairspray. At night, either pull a few front pieces out to soften the look or add a glitzy headband.

## Messy Fishtail

Pull off a lived-in braid the natural way. Start with a clean fishtail braid in the morning and let it naturally transition to messy-chic—pieces will fall out of the plait over time. At the end of the day, use a dry shampoo at the roots to make the entire style look lived in. Add a bow or leather cuff at the tip of the braid for subtle structure.

RELATED:

- Headbands 101: Taylor Swift Taught a Master Class on the Subject
- The Game-Changing Oil for Dry Hair and Split Ends
- 30-Second Hair Hacks That Tame Static

KEYWORDS: braids,buns,Emma Stone,jaime king,Jessica Alba,New Year's Eve,Waves

SEE MORE
SEE LESS
OLDER NEWER
Tea Party Time! The Ultimate Guide to Tea
The Charitable Fitness Endeavor That’s Changing the Game
What We're Reading

Hide comments Show comments
Loading Comments...

- Facebook
- Twitter
- Pinterest
- Gplus
- Instragram

More On Self
Emma Watson Shows Us How a Super-Nude Pe
FDA Puts the Smackdown on Indoor Tanning
Hilary Duff Is a Powerhouse
How Many Days a Week Should You Exercise
6 High-Fat Foods That Are Good for You